# lgpio Package

lgpio is a module for Linux Single Board Computers (SBC) which allows control of the General Purpose Input Outputs (GPIO).

## Features

* reading and writing GPIO singly and in groups
* software timed PWM and waves
* callbacks on GPIO level change
* notifications via pipe on GPIO level change
* I2C wrapper
* SPI wrapper
* serial link wrapper

## Installation

pypy can not handle Linux libararies properly at the moment.

You need to install the lgpio module from the lg archive.

See http://abyz.me.uk/lg/download.html

